@@ -2,7 +2,7 @@
                                mainwindow.cpp
                              -------------------
     begin                : Mo 16.03.2009
-    copyright            : (C) 2009-2021 by Andre Simon
+    copyright            : (C) 2009-2022 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -873,7 +873,7 @@ void MainWindow::on_action_About_Highlight_triggered()
     QMessageBox::about( this, "About Highlight",
                         QString("Highlight is a code to formatted text converter.\n\n"
                                 "Highlight GUI %1\n"
-                                "Copyright (C) 2002-2021 Andre Simon <a.simon at mailbox.org>\n\n"
+                                "Copyright (C) 2002-2022 Andre Simon <a.simon at mailbox.org>\n\n"
                                 "Artistic Style Classes\n(C) 1998-2002 Tal Davidson\n"
                                 "Copyright (C) 2006-2018 Jim Pattee <jimp03 at email.com>\n\n"
                                 "Diluculum Lua wrapper\n"
@@ -1995,11 +1995,6 @@ void MainWindow::on_actionVisit_website_triggered()
     QDesktopServices::openUrl(QUrl("http://www.andre-simon.de/"));
 }
 
-void MainWindow::on_actionDock_floating_panels_toggled(bool arg1)
-{
-    ui->dockWidget->setFloating(arg1);
-}
-
 void MainWindow::on_pbPluginReadFilePath_clicked()
 {
     selectSingleFile(ui->lePluginReadFilePath, tr("Choose a plug-in input file"), "*");
