@@ -2,8 +2,8 @@
                           stylecolour.h  -  description
                              -------------------
     begin                : Die Nov 5 2002
-    copyright            : (C) 2002 by Andre Simon
-    email                : andre.simon1@gmx.de
+    copyright            : (C) 2002-2021 by Andre Simon
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
@@ -71,7 +71,6 @@ public:
     */
     void setRGB ( const string & colourString );
 
-
     /** Sets red value
         \param red New red value */
     void setRed ( const string & red );
@@ -87,20 +86,21 @@ public:
     /**  @param type Output type
          @return Red value in color representation according to output type */
     string getRed ( OutputType type ) const;
+
     /**  @param type Output type
          @return Green value in color representation according to output type */
     string getGreen ( OutputType type ) const;
+
     /**  @param type Output type
          @return Blue value in color representation according to output type */
     string getBlue ( OutputType type ) const;
-    
-    
+
     /**  @return red value */
     int getRed () const;
-    
+
     /**  @return green value */
     int getGreen () const;
-    
+
     /**  @return blue value */
     int getBlue () const;
 
